import { ApplicationRef, ComponentFactoryResolver, Injector, NgModuleRef, NgZone, Type, ViewContainerRef } from '@angular/core';
import { ShowModalOptions, View, ViewBase } from '@nativescript/core';
import { Subject } from 'rxjs';
import { NSLocationStrategy } from '../router/ns-location-strategy';
import * as i0 from "@angular/core";
export type BaseShowModalOptions = Pick<ShowModalOptions, Exclude<keyof ShowModalOptions, 'closeCallback' | 'context'>>;
export interface ModalDialogOptions extends BaseShowModalOptions {
    context?: any;
    viewContainerRef?: ViewContainerRef;
    moduleRef?: NgModuleRef<any>;
    target?: View;
    /**
     * Use context data as component instance properties
     */
    useContextAsComponentProps?: boolean;
}
export interface ShowDialogOptions extends ModalDialogOptions {
    containerRef?: ViewContainerRef;
    /**
     * which container to attach the change detection
     * if not specified, attaches to the ApplicationRef (recommended)
     */
    attachToContainerRef?: ViewContainerRef;
    injector: Injector;
    context: any;
    doneCallback: any;
    pageFactory?: any;
    parentView: ViewBase;
    resolver: ComponentFactoryResolver;
    type: Type<any>;
}
export declare class ModalDialogParams {
    context: any;
    closeCallback: (...args: any[]) => any;
    constructor(context: any, closeCallback: (...args: any[]) => any);
}
export declare class ModalDialogService {
    private location;
    private zone;
    private appRef;
    private defaultInjector;
    /**
     * Any opened ModalDialogParams in order of when they were opened (Most recent on top).
     * This can be used when you need access to ModalDialogParams outside of the component which had them injected.
     * Each is popped off as modals are closed.
     */
    openedModalParams: Array<ModalDialogParams>;
    _closed$: Subject<ModalDialogParams>;
    constructor(location: NSLocationStrategy, zone: NgZone, appRef: ApplicationRef, defaultInjector: Injector);
    /**
     * Emits anytime a modal is closed with the ModalDialogParams which were injected into the component which is now closing.
     * For example, can be used to wire up Rx flows outside the scope of just the component being handled.
     */
    get closed$(): Subject<ModalDialogParams>;
    showModal(type: Type<any>, options?: ModalDialogOptions): Promise<any>;
    private _showDialog;
    static ɵfac: i0.ɵɵFactoryDeclaration<ModalDialogService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ModalDialogService>;
}
